package waste

import (
	"reflect"
	"testing"
)

func TestWasteService_parseWaste(t *testing.T) {
	type args struct {
		text string
	}
	tests := []struct {
		name string
		args args
		want *WasteEntity
	}{
		{
			name: "full",
			args: args{
				text: "Транспорт: такси 2 200",
			},
			want: &WasteEntity{
				CategoryName: "транспорт",
				Name:         "такси",
				Amount:       2,
				Price:        20000,
			},
		},
		{
			name: "full without amount",
			args: args{
				text: "Транспорт: такси 200",
			},
			want: &WasteEntity{
				CategoryName: "транспорт",
				Name:         "такси",
				Amount:       1,
				Price:        20000,
			},
		},
		{
			name: "without category",
			args: args{
				text: "такси 2 200",
			},
			want: &WasteEntity{
				Name:   "такси",
				Amount: 2,
				Price:  20000,
			},
		},
		{
			name: "without amount",
			args: args{
				text: "такси 200",
			},
			want: &WasteEntity{
				Name:   "такси",
				Amount: 1,
				Price:  20000,
			},
		},
		{
			name: "р",
			args: args{
				text: "такси 200р",
			},
			want: &WasteEntity{
				Name:   "такси",
				Amount: 1,
				Price:  20000,
			},
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			s := &WasteService{}
			if got := s.parseWaste(tt.args.text); !reflect.DeepEqual(got, tt.want) {
				t.Errorf("WasteService.parseWaste() = %v, want %v", got, tt.want)
			}
		})
	}
}
